"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.JwtService = void 0;
const tslib_1 = require("tslib");
const core_1 = require("@loopback/core");
const rest_1 = require("@loopback/rest");
const util_1 = require("util");
const keys_1 = require("../keys");
const jwt = require('jsonwebtoken');
const signAsync = (0, util_1.promisify)(jwt.sign);
const verifyAsync = (0, util_1.promisify)(jwt.verify);
const decodeAsync = (0, util_1.promisify)(jwt.decode);
let JwtService = class JwtService {
    constructor(jwtSecret, jwtExpiresIn) {
        this.jwtSecret = jwtSecret;
        this.jwtExpiresIn = jwtExpiresIn;
    }
    async verifyToken(token) {
        if (!token) {
            throw new rest_1.HttpErrors.Unauthorized(`Error verifying token : 'token' is null`);
        }
        let userProfile;
        try {
            const decodedToken = await verifyAsync(token, this.jwtSecret);
            userProfile = Object.assign({
                name: decodedToken.name,
                id: decodedToken.id,
                role: decodedToken.role,
                permissions: decodedToken.permissions,
                userTenantId: decodedToken.userTenantId,
            });
        }
        catch (error) {
            throw new rest_1.HttpErrors.Unauthorized(`Error verifying token : ${error.message}`);
        }
        return userProfile;
    }
    async generateToken(userProfile) {
        if (!userProfile) {
            throw new rest_1.HttpErrors.Unauthorized('Error generating token : userProfile is null');
        }
        const userInfoForToken = {
            id: userProfile.id,
            name: userProfile.name,
            role: userProfile.role,
            permissions: userProfile.permissions,
            userTenantId: userProfile.userTenantId,
        };
        // Generate a JSON Web Token
        let token;
        try {
            token = await signAsync(userInfoForToken, process.env.JWT_SECRET, {
                expiresIn: Number(this.jwtExpiresIn),
            });
        }
        catch (error) {
            throw new rest_1.HttpErrors.Unauthorized(`Error encoding token : ${error}`);
        }
        return token;
    }
    async decodeToken(token) {
        return decodeAsync(token);
    }
};
JwtService = tslib_1.__decorate([
    (0, core_1.injectable)({ scope: core_1.BindingScope.TRANSIENT }),
    tslib_1.__param(0, (0, core_1.inject)(keys_1.AuthServiceBindings.TOKEN_SECRET)),
    tslib_1.__param(1, (0, core_1.inject)(keys_1.AuthServiceBindings.TOKEN_EXPIRES_IN)),
    tslib_1.__metadata("design:paramtypes", [String, String])
], JwtService);
exports.JwtService = JwtService;
//# sourceMappingURL=jwt.service.js.map