"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DefaultUserModifyRepository = void 0;
const rest_1 = require("@loopback/rest");
const default_soft_crud_repository_base_1 = require("./default-soft-crud.repository.base");
class DefaultUserModifyRepository extends default_soft_crud_repository_base_1.DefaultSoftCrudRepository {
    constructor(entityClass, dataSource, currentUser) {
        super(entityClass, dataSource, currentUser);
        this.currentUser = currentUser;
    }
    async create(entity, options) {
        var _a, _b, _c;
        if (!this.currentUser) {
            throw new rest_1.HttpErrors.Forbidden("Invalid Credentials" /* AuthErrorKeys.InvalidCredentials */);
        }
        const uid = (_b = (_a = this.currentUser) === null || _a === void 0 ? void 0 : _a.userTenantId) !== null && _b !== void 0 ? _b : (_c = this.currentUser) === null || _c === void 0 ? void 0 : _c.id;
        entity.createdBy = uid;
        entity.modifiedBy = uid;
        return super.create(entity, options);
    }
    async createAll(entities, options) {
        var _a, _b, _c;
        if (!this.currentUser) {
            throw new rest_1.HttpErrors.Forbidden("Invalid Credentials" /* AuthErrorKeys.InvalidCredentials */);
        }
        const uid = (_b = (_a = this.currentUser) === null || _a === void 0 ? void 0 : _a.userTenantId) !== null && _b !== void 0 ? _b : (_c = this.currentUser) === null || _c === void 0 ? void 0 : _c.id;
        entities.forEach(entity => {
            entity.createdBy = uid !== null && uid !== void 0 ? uid : '';
            entity.modifiedBy = uid !== null && uid !== void 0 ? uid : '';
        });
        return super.createAll(entities, options);
    }
    async save(entity, options) {
        var _a, _b, _c;
        if (!this.currentUser) {
            throw new rest_1.HttpErrors.Forbidden("Invalid Credentials" /* AuthErrorKeys.InvalidCredentials */);
        }
        const uid = (_b = (_a = this.currentUser) === null || _a === void 0 ? void 0 : _a.userTenantId) !== null && _b !== void 0 ? _b : (_c = this.currentUser) === null || _c === void 0 ? void 0 : _c.id;
        entity.modifiedBy = uid;
        return super.save(entity, options);
    }
    async update(entity, options) {
        var _a, _b, _c;
        if (!this.currentUser) {
            throw new rest_1.HttpErrors.Forbidden("Invalid Credentials" /* AuthErrorKeys.InvalidCredentials */);
        }
        const uid = (_b = (_a = this.currentUser) === null || _a === void 0 ? void 0 : _a.userTenantId) !== null && _b !== void 0 ? _b : (_c = this.currentUser) === null || _c === void 0 ? void 0 : _c.id;
        entity.modifiedBy = uid;
        return super.update(entity, options);
    }
    async updateAll(data, where, options) {
        var _a, _b, _c;
        if (!this.currentUser) {
            throw new rest_1.HttpErrors.Forbidden("Invalid Credentials" /* AuthErrorKeys.InvalidCredentials */);
        }
        const uid = (_b = (_a = this.currentUser) === null || _a === void 0 ? void 0 : _a.userTenantId) !== null && _b !== void 0 ? _b : (_c = this.currentUser) === null || _c === void 0 ? void 0 : _c.id;
        data.modifiedBy = uid;
        return super.updateAll(data, where, options);
    }
    async updateById(id, data, options) {
        var _a, _b, _c;
        if (!this.currentUser) {
            throw new rest_1.HttpErrors.Forbidden("Invalid Credentials" /* AuthErrorKeys.InvalidCredentials */);
        }
        const uid = (_b = (_a = this.currentUser) === null || _a === void 0 ? void 0 : _a.userTenantId) !== null && _b !== void 0 ? _b : (_c = this.currentUser) === null || _c === void 0 ? void 0 : _c.id;
        data.modifiedBy = uid;
        return super.updateById(id, data, options);
    }
    async replaceById(id, data, options) {
        var _a, _b, _c;
        if (!this.currentUser) {
            throw new rest_1.HttpErrors.Forbidden("Invalid Credentials" /* AuthErrorKeys.InvalidCredentials */);
        }
        const uid = (_b = (_a = this.currentUser) === null || _a === void 0 ? void 0 : _a.userTenantId) !== null && _b !== void 0 ? _b : (_c = this.currentUser) === null || _c === void 0 ? void 0 : _c.id;
        data.modifiedBy = uid;
        return super.replaceById(id, data, options);
    }
}
exports.DefaultUserModifyRepository = DefaultUserModifyRepository;
//# sourceMappingURL=default-user-modify-repository.base.js.map